<?php

namespace App\Http\Controllers\admin;


use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Session;
use App\admin\AdminModel;
use Illuminate\Contracts\Auth\Authenticatable;

class AuthController extends Controller
{
    const ADMIN_TIMEZONE = 'admin_timezone_key';
    const ADMIN_TIMEZONE_OFFSET = 'admin_timezone_offset_key';

    //=========================== Admin Login ======================================== 
    public function login()
    {
        if (Auth::guard('admin')->check()) {
            return redirect('admin/dashboard');
        } else {
            return view('admin.auth.login');
        }
    }

    public function loginData(Request $req)
    {

        $data = $req->validate(
            [
                'email' => 'required|email',
                'password' => 'required'
            ],
            [
                'email.required' => 'Enter Registered Email Id',
                'password.required' => 'Enter Password',
                'email.email' => 'Enter Valid Email Id'
            ]
        );


        $credentials = $req->only('email', 'password');
        // dd($credentials);
        if (auth('admin')->attempt($credentials)) {

            $user = auth('admin')->user();

            if ($user) {
                //$this->session->set_userdata(ADMIN_TIMEZONE, $this->input->post('timezone'));
                //$this->session->set_userdata(ADMIN_TIMEZONE_OFFSET, $this->input->post('timezone_offset'));

                session([self::ADMIN_TIMEZONE => $req->input('timezone'), self::ADMIN_TIMEZONE_OFFSET => $req->input('timezone_offset')]);

                $req->session()->put(['admin_id' => $user->id, 'admin_name' => $user->fullname]);
                return redirect('/admin/dashboard')->with('success', 'You are Logged in successfully.');
            }
        } else {
            return back()->with('error', 'Invalid email and password');
        }
        return back()->with('error', 'User not found.');
    }


    //==========================Admin Profile=======================================
    public function Profile()
    {
        $id = Auth::guard('admin')->id();
        //dd($id);
        $user = AdminModel::find($id);
        return view('admin.auth.profile', compact('user'));
    }

    //======================Admin Profile Update====================================
    public function editprofile(Request $req)
    {
        //$id = Auth::guard('admin')->id();
        $validatedData = $req->validate([
            'fullname' => 'required|min:3|max:64',
            'country_code' => 'required',
            'phone_number' => 'required|min:11|numeric',
            'email' => 'required|email',
        ]);

        $user = AdminModel::find($req->input('id'));

        $user->fullname = $validatedData['fullname'];
        $user->country_code = $validatedData['country_code'];
        $user->phone_number = $validatedData['phone_number'];
        $user->email = $validatedData['email'];

        $user->save();

        return response()->json(['status' => 'success', 'message' => 'Data Update Successfully']);
    }

    //======================= Chnage Password =============================
    public function adminPassword()
    {
        $id = Auth::guard('admin')->id();

        $data = AdminModel::find($id);
        //dd($data);
        return view('admin.auth.changepassword', compact('data'));
    }


    public function changePassword(Request $req)
    {

        $validatedData = $req->validate([
            'password' => 'required|min:8',
            'confirm' => 'required|same:password',
        ], [
            'password.required' => 'Enter New Password',
            'confirm.required' => 'Enter Confirm Password',
            'confirm.same' => 'The confirmation password does not match the password.',
        ]);
        // dd($req->input('password'), $req->input('confirm'));
        AdminModel::whereId(Auth::guard('admin')->id())->update([
            'password' => Hash::make($req->password)
        ]);
        //$2y$10$3T5zoYO1MJW/CQZEwSGI7OEQJgzsbLCvVq/np8xRgMkdeqV8JYPiG
        Session::put('success', 'Password Update Successfully');
        return redirect()->back();
    }
    //=========================== Admin Logout ======================================== 
    public function logout()
    {
        //dd('hello');
        Auth::guard('admin')->logout();
        Session::flush();
        Session::put('success', 'You are logout sucessfully');
        //return redirect('admin');
        return response()->json(['status' => 'success', 'message' => 'Logout Successfully']);
    }


}
